@@ -10,7 +10,7 @@ impl_vector!(Vector2 { x, y }, 2);
 impl<T> TuplableVector<T, { Vector2::<()>::LEN }> for Vector2<T> {
     type Output = (T, T);
 
-    fn as_tuple(self) -> Self::Output {
+    fn to_tuple(self) -> Self::Output {
         return (self.x, self.y);
     }
 }
@@ -25,7 +25,7 @@ impl<T> From<(T, T)> for Vector2<T> {
 }
 
 fn main() {
-    let tuple = Vector2::new("Vector", "2").as_tuple();
+    let tuple = Vector2::new("Vector", "2").to_tuple();
     println!("Vector as Tuple: {:?}", tuple);
     assert_eq!(tuple, ("Vector", "2"));
 }
\ No newline at end of file
