@@ -148,14 +148,15 @@ macro_rules! impl_vector {
 
         impl<T> $crate::Vector<T, $len> for $Vector<T> {
             #[inline]
-            fn name(&self) -> &'static str { return Self::NAME; }
+            fn name(&self) -> &'static str {
+                return Self::NAME;
+            }
 
-            #[inline]
-            fn as_array(self) -> [T; $len] {
+            fn to_array(self) -> [T; $len] {
                 return [ $(self.$field), + ];
             }
 
-            fn as_vec(self) -> std::vec::Vec<T> {
+            fn to_vec(self) -> std::vec::Vec<T> {
                 let mut vec = std::vec::Vec::with_capacity(Self::LEN);
                 $( vec.push(self.$field); ) +
                 return vec;
@@ -265,7 +266,6 @@ macro_rules! impl_vector {
 
                 if m == num_traits::zero::<T>() { return self.zero(); }
 
-                // NOTE: This `sqrt()` call is a bottleneck, should be replaced with a fast square-root algorithm
                 let m = m.sqrt();
 
                 return Self {
@@ -430,6 +430,7 @@ macro_rules! impl_vector {
         impl<T: core::ops::BitAnd<Output = T>> core::ops::BitAnd for $Vector<T> {
             type Output = Self;
         
+            #[inline]
             fn bitand(self, other: Self) -> Self::Output {
                 return Self {
                     $( $field: self.$field & other.$field ), +
@@ -438,6 +439,7 @@ macro_rules! impl_vector {
         }
 
         impl<T: core::ops::BitAnd<Output = T> + Copy> core::ops::BitAndAssign for $Vector<T> {
+            #[inline]
             fn bitand_assign(&mut self, other: Self) {
                 *self = Self {
                     $( $field: self.$field & other.$field ), +
@@ -448,6 +450,7 @@ macro_rules! impl_vector {
         impl<T: core::ops::BitOr<Output = T>> core::ops::BitOr for $Vector<T> {
             type Output = Self;
         
+            #[inline]
             fn bitor(self, other: Self) -> Self::Output {
                 return Self {
                     $( $field: self.$field | other.$field ), +
@@ -456,6 +459,7 @@ macro_rules! impl_vector {
         }
 
         impl<T: core::ops::BitOr<Output = T> + Copy> core::ops::BitOrAssign for $Vector<T> {
+            #[inline]
             fn bitor_assign(&mut self, other: Self) {
                 *self = Self {
                     $( $field: self.$field | other.$field ), +
@@ -466,6 +470,7 @@ macro_rules! impl_vector {
         impl<T: core::ops::BitXor<Output = T>> core::ops::BitXor for $Vector<T> {
             type Output = Self;
         
+            #[inline]
             fn bitxor(self, other: Self) -> Self::Output {
                 return Self {
                     $( $field: self.$field ^ other.$field ), +
@@ -474,6 +479,7 @@ macro_rules! impl_vector {
         }
 
         impl<T: core::ops::BitXor<Output = T> + Copy> core::ops::BitXorAssign for $Vector<T> {
+            #[inline]
             fn bitxor_assign(&mut self, other: Self) {
                 *self = Self {
                     $( $field: self.$field ^ other.$field ), +
@@ -609,7 +615,7 @@ impl<T> TuplableVector<T, { Vector2::<()>::LEN }> for Vector2<T> {
     type Output = (T, T);
 
     #[inline]
-    fn as_tuple(self) -> Self::Output {
+    fn to_tuple(self) -> Self::Output {
         return (self.x, self.y);
     }
 }
@@ -628,7 +634,7 @@ impl<T> TuplableVector<T, { Vector3::<()>::LEN }> for Vector3<T> {
     type Output = (T, T, T);
 
     #[inline]
-    fn as_tuple(self) -> Self::Output {
+    fn to_tuple(self) -> Self::Output {
         return (self.x, self.y, self.z);
     }
 }
@@ -647,7 +653,7 @@ impl<T> TuplableVector<T, { Vector4::<()>::LEN }> for Vector4<T> {
     type Output = (T, T, T, T);
 
     #[inline]
-    fn as_tuple(self) -> Self::Output {
+    fn to_tuple(self) -> Self::Output {
         return (self.x, self.y, self.z, self.w);
     }
 }
